@@ -10,7 +10,7 @@
 #include <pk11pqg.h>
 #include <secerr.h>
 #include <nspr.h>
-#include <key.h>
+#include <keyhi.h>
 #include <secitem.h>
 
 #include <jss_bigint.h>
@@ -352,17 +352,11 @@ Java_org_mozilla_jss_pkcs11_PK11PrivKey_getUniqueID
      * Write the key id to a new byte array
      ***************************************************/
     PR_ASSERT(idItem->len > 0);
-    byteArray = (*env)->NewByteArray(env, idItem->len);
-    if(byteArray == NULL) {
+    byteArray = JSS_ToByteArray(env, idItem->data, idItem->len);
+    if (byteArray == NULL) {
         ASSERT_OUTOFMEM(env);
         goto finish;
     }
-    (*env)->SetByteArrayRegion(env, byteArray, 0, idItem->len,
-                (jbyte*)idItem->data);
-    if( (*env)->ExceptionOccurred(env) != NULL) {
-        PR_ASSERT(PR_FALSE);
-        goto finish;
-    }
 
 finish:
     if(idItem != NULL) {
@@ -709,7 +703,7 @@ Java_org_mozilla_jss_pkcs11_PK11RSAPrivateKey_getModulusByteArray
     length = (jint)publicKey->u.rsa.modulus.len;
 
     // create byte array
-    array = (*env)->NewByteArray(env, length);
+    array = JSS_ToByteArray(env, value, length);
 
     // check byte array creation
     if (array == NULL) {
@@ -717,9 +711,6 @@ Java_org_mozilla_jss_pkcs11_PK11RSAPrivateKey_getModulusByteArray
         goto finish;
     }
 
-    // copy modulus into byte array
-    (*env)->SetByteArrayRegion(env, array, 0, length, value);
-
 finish:
     if (publicKey) {
         SECKEY_DestroyPublicKey(publicKey);
